# API

## Preprocessing

```{eval-rst}
.. module:: delnx.pp
.. currentmodule:: delnx

.. autosummary::
    :toctree: generated

    pp.basic_preproc
    pp.elaborate_example
```

## Tools

```{eval-rst}
.. module:: delnx.tl
.. currentmodule:: delnx

.. autosummary::
    :toctree: generated

    tl.basic_tool
```

## Plotting

```{eval-rst}
.. module:: delnx.pl
.. currentmodule:: delnx

.. autosummary::
    :toctree: generated

    pl.basic_plot
    pl.BasicClass
```
